@@ -76,10 +76,10 @@ bool DLL_LOCAL looksLikeHtmlAndNotAUrl(QString str) {
 }
 
 PdfConverterPrivate::PdfConverterPrivate(PdfGlobal & s, PdfConverter & o) :
-	settings(s), pageLoader(s.load, true),
+	settings(s), pageLoader(s.load, settings.dpi, true),
 	out(o), printer(0), painter(0)
 #ifdef __EXTENSIVE_WKHTMLTOPDF_QT_HACK__
-    , webPrinter(0), measuringHFLoader(s.load), hfLoader(s.load), tocLoader1(s.load), tocLoader2(s.load)
+	, webPrinter(0), measuringHFLoader(s.load, settings.dpi), hfLoader(s.load, settings.dpi), tocLoader1(s.load, settings.dpi), tocLoader2(s.load, settings.dpi)
 	, tocLoader(&tocLoader1), tocLoaderOld(&tocLoader2)
     , outline(0), currentHeader(0), currentFooter(0)
 #endif
@@ -265,7 +265,7 @@ qreal PdfConverterPrivate::calculateHeaderHeight(PageObject & object, QWebPage &
 
 QPrinter * PdfConverterPrivate::createPrinter(const QString & tempFile) {
     QPrinter * printer = new QPrinter(settings.resolution);
-    if (settings.dpi != -1) printer->setResolution(settings.dpi);
+    printer->setResolution(settings.dpi);
     //Tell the printer object to print the file <out>
 
     printer->setOutputFileName(tempFile);
@@ -344,7 +344,7 @@ void PdfConverterPrivate::pagesLoaded(bool ok) {
 	  lout = tempOut.create(".pdf");
 
 	printer = new QPrinter(settings.resolution);
-	if (settings.dpi != -1) printer->setResolution(settings.dpi);
+	printer->setResolution(settings.dpi);
 	//Tell the printer object to print the file <out>
 
 	printer->setOutputFileName(lout);
@@ -651,6 +651,9 @@ void PdfConverterPrivate::endPage(PageObject & object, bool hasHeaderFooter, int
 		updateWebSettings(header->settings(), object.settings.web);
 		painter->save();
 		painter->resetTransform();
+		QPalette pal = header->palette();
+		pal.setBrush(QPalette::Base, Qt::transparent);
+		header->setPalette(pal);
 		double spacing = s.header.spacing * printer->height() / printer->heightMM();
         // clear vertical margins for proper header rendering
         printer->setPageMargins(leftMargin, 0, rightMargin, 0, settings.margin.left.second);
@@ -680,6 +683,9 @@ void PdfConverterPrivate::endPage(PageObject & object, bool hasHeaderFooter, int
 		updateWebSettings(footer->settings(), object.settings.web);
 		painter->save();
 		painter->resetTransform();
+		QPalette pal = footer->palette();
+		pal.setBrush(QPalette::Base, Qt::transparent);
+		footer->setPalette(pal);
 		double spacing = s.footer.spacing * printer->height() / printer->heightMM();
 		painter->translate(0, printer->height()+ spacing);
         // clear vertical margins for proper header rendering
@@ -1047,7 +1053,7 @@ void PdfConverterPrivate::printDocument() {
 	currentPhase = 2;
 #endif
 	emit out.phaseChanged();
-	convertionDone = true;
+	conversionDone = true;
 	emit out.finished(true);
 
 	qApp->exit(0); // quit qt's event handling
